@@ -11,19 +11,15 @@
 #include "settings.h"
 
 // KDEGames
-#include <kdegames_version.h>
-#include <KgTheme>
-#include <KgThemeProvider>
+#include <KGameTheme>
+#include <KGameThemeProvider>
 
 #include <QCursor>
 
-static KgThemeProvider *provider()
+static KGameThemeProvider *provider()
 {
-    KgThemeProvider *prov = new KgThemeProvider;
+    KGameThemeProvider *prov = new KGameThemeProvider;
     prov->discoverThemes(
-#if KDEGAMES_VERSION < QT_VERSION_CHECK(7, 4, 0)
-        "appdata",
-#endif
         QStringLiteral("themes"),   // theme file location
         QStringLiteral("robotkill") // default theme file name
     );
